///////////////////////////////////////
//
// LICENSE NOTICE:
//
// Epic GTA2 Script Decompiler, version 1.0.1, November 16th, 2011
//
// Copyright (C) 2011 T.M. (tmdevmail at gmail.com)
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the author(s) be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// excluding commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation is required.
// 2. Altered source versions must be plainly marked as such, and must not be
//    misrepresented as being the original software. All versions source code must
//    be made freely available for everyone.
// 3. build_credits() function may not be altered and its output must remain in the
//    decompiler output as the first line of text. Contact the author if you desire
//    to be credited on that line of text.
// 4. This notice may not be removed or altered from any source distribution.
//
///////////////////////////////////////

//
// ALL ARRAYS MUST START WITH "SCR_"
// enum_cstr() function takes name without SCR_ prefix!
// using char* instead of std::string for performance and exe size reasons: strings add extra overhead for each element in an array.

const char *SCR_BLOCK_FACES[] = {"", "LEFT", "RIGHT", "TOP", "BOTTOM", "LID"};
const char *SCR_DOOR_OPENTYPES[] = {"ANY_PLAYER", "ANY_CAR", "ONE_CAR", "ONE_MODEL", "ONE_CHAR_ON_FOOT", "", "ANY_PLAYER_ONE_CAR"};
const char *SCR_DOOR_CLOSETYPES[] = {"CLOSE_NEVER", "CLOSE_TIME_DELAY", "CLOSE_WHEN_CLEAR", "CLOSE_WHEN_OPEN_RULE_FAILS"};
const char *SCR_DOOR_FLIPTYPES[] = {"NOT_FLIPPED", "FLIP_RIGHT"};
const char *SCR_DOOR_REVERSED[] = {"NOT_REVERSED", "REVERSED"};
const char *SCR_CRANETYPES[] = {"FIRST", "SECOND"};
const char *SCR_ONOFF[] = {"OFF", "ON"};
const char *SCR_BLOCK_FLIPTYPES[] = {"NOT_FLIP", "FLIP"};
const char *SCR_BLOCK_FLATTYPES[] = {"NOT_FLAT", "FLAT"};
const char *SCR_BLOCKTYPES[] = {"AIR", "ROAD", "PAVEMENT", "FIELD"};
const char *SCR_WALL_TYPES[] = {"NOT_WALL", "WALL"};
const char *SCR_BULLETWALL_TYPES[] = {"NOT_BULLET", "BULLET"};
const char *SCR_ROT_LIST[] = {"0", "90", "180", "270"}; // easier to have them as strings, no need to make own function just for these error handling.
const char *SCR_DROPS[] = {"DONT_DROP", "DO_DROP"};
const char *SCR_CARDAMAGEPOS[] = {"FRONT_LEFT", "FRONT_RIGHT", "BACK_LEFT", "BACK_RIGHT", "WINDOW"};
const char *SCR_PLAY_FOR[] = {"PLAY_FOREVER", "PLAY_INSTANT"};
const char *SCR_ACCURACY[] = {"CRAP_SHOT", "NORMAL_SHOT", "CRACK_SHOT"};
const char *SCR_BONUS_WHICH[] = {"NOTHING", "SCORE", "MULT", "LIVES"};
const char *SCR_BONUS[] = {"NO_BONUS", "BONUS_1", "BONUS_2", "BONUS_3"};
const char *SCR_BRAVERY[] = {"COWARD", "AVERAGE", "LOONY"};
const char *SCR_CAR_OVERLAY[] = {"DUMMY_GRAPHIC", "GANG_GRAPHIC", "EMERG_GRAPHIC"};
const char *SCR_COLOURS[] = {"", "YELLOW", "RED", "GREEN", "BLUE"};
const char *SCR_EXCLUSIVE[] = {"NOT_EXCLUSIVE", "EXCLUSIVE"};
const char *SCR_FOLLOWER_TYPE[] = {"EMPTY", "CHAIN", "MOB"};
const char *SCR_LOCKS[] = {"NO_LOCK", "LOCKED", "LOCKOUT_THIEF", "UNLOCKED", "LOCKED_PERMANENTLY", "LOCKOUT_PLAYER"};
const char *SCR_THREAT_REACTION[] = {"NO_REACTION", "REACT_AS_EMERGENCY", "REACT_AS_NORMAL", "RUN_AWAY"};
const char *SCR_THREAT_SEARCH[] = {"NO_THREATS", "LINE_OF_SIGHT", "AREA", "AREA_PLAYER_THREAT_ONLY", "LINE_OF_SIGHT_PLAYER_THREAT_ONLY", "AREA_PLAYER_ONLY", "LINE_OF_SIGHT_PLAYER_ONLY"};
const char *SCR_TRAIN_CARTYPE[] = {"NO_CARRIAGE", "PASSENGER", "FREIGHT", "BOXCAR"};


const char *SCR_RADIO_STATIONS[] = {
	"", "", "STATION_DOWNTOWN", "STATION_RESIDENTIAL", "STATION_INDUSTRIAL", "STATION_ZAIBATSU", "STATION_YAKUZA", "STATION_LOONIE", 
	"STATION_REDNECK", "STATION_SCIENTIST", "STATION_KRISHNA", "STATION_RUSSIAN"
};

const char *SCR_WEAPONS[] = {
	"PISTOL", "MACHINE_GUN", "ROCKET_LAUNCHER", "ELECTRO_GUN", "MOLOTOV", "GRENADE", "SHOTGUN", "ELECTRO_BATON", "FLAME_THROWER", "SILENCED_MACHINE_GUN", 
	"DUAL_PISTOL", "WEAPON_11", "WEAPON_12", "WEAPON_13", "WEAPON_14", "CAR_BOMB", "CAR_OIL", "CAR_MINE", "CAR_MACHINE_GUN", "TANK_GUN", "WATER_CANNON", 
	"CAR_FLAMETHROWER", "JEEP_GUN", "CAR_BOMB_INSTANT", "WEAPON_24", "WEAPON_25", "WEAPON_26", "WEAPON_27", "NO_WEAPON"
};

const char *SCR_KILLED_BY[] = {
	"NOT_DAMAGED", "BY_VEHICLE", "BY_TRAIN_TRACKS", "BY_OWN_VEHICLE", "BY_EXPLOSION", "BY_DROWNING", "BY_POLICE", "BY_DUMMY_CAR", "BY_PUBLIC_TRANSPORT", 
	"BY_UNKNOWN_WEAPON", "BY_PUNCH", "BY_GUN", "BY_CAR_BOMB", "BY_FIRE", "BY_FLAMETHROWER", "BY_GRENADE", "BY_MOLOTOV", "BY_ROCKET_LAUNCHER", "BY_ELECTRO_WEAPON", 
	"BY_SHOTGUN", "BY_WATER_CANNON", "BY_CAR_MINE", "BY_ANY_FOOT_WEAPON", "BY_ANY_WEAPON"
};

const char *SCR_OCCUPATIONS[] = {
	"PLAYER", "", "", "DUMMY", "", "DRIVER", "", "", "", "", "", "", "", "", "PSYCHO", "MUGGER", 
	"CARTHIEF", "BANK_ROBBER", "CRIMINAL", "", "", "", "ELVIS", "", "POLICE", "SWAT", "FBI", "ARMY", "GUARD", "", "", "", 
	"GUARD_AGAINST_PLAYER", "CRIMINAL_TYPE1", "CRIMINAL_TYPE2", "SPECIAL_GROUP_MEMBER", "TANK_DRIVER", "", "FIREMAN", "ROAD_BLOCK_TANK_MAN", "", "DRONE", "", 
	"STAND_STILL_BLOKE", "ELVIS_LEADER", "REFUGEES", "ANY_LAW_ENFORCEMENT", "ANY_EMERGENCY_SERVICE_MAN", "ANY_GANG_MEMBER", "ANY_ELVIS", "", "NO_OCCUPATION"
};

const char *SCR_OBJECTIVES[] = {
	"NO_OBJ", "FLEE_ON_FOOT_TILL_SAFE", "FLEE_CHAR_ON_FOOT_TILL_SAFE", "FLEE_CHAR_ON_FOOT_ALWAYS", "", "", "", "", "", "", "", "", "GOTO_AREA_ON_FOOT", 
	"", "GOTO_AREA_IN_CAR", "", "GOTO_CHAR_ON_FOOT", "", "", "KILL_CHAR_ANY_MEANS", "KILL_CHAR_ON_FOOT", "", "", "", "GUARD_SPOT", "GUARD_AREA", 
	"WAIT_ON_FOOT", "WAIT_IN_CAR", "", "", "", "", "", "", "", "ENTER_CAR_AS_DRIVER", "LEAVE_CAR", "", "", "", "", "", "", "", "", "", "", "", "", 
	"", "", "", "", "", "", "FOLLOW_CAR_IN_CAR", "FOLLOW_CAR_ON_FOOT_WITH_OFFSET", "FIRE_AT_OBJECT_FROM_VEHICLE", "DESTROY_OBJECT", "DESTROY_CAR"
};

const char *SCR_SOUNDS[] = {
	"", "WIND", "SKID", "NIGHT_CLUB", "BAR", "GENERATOR_RUMBLE", "WORKSHOP", "VAT", "CHURCH_SINGING", "TEMPLE_CHANT", "INDUSTRIAL_HIGH", 
	"HUMAN_ABATTOIR", "FUNNY_FARM", "BANK_ALARM", "INDUSTRIAL_LOW", "PORTA_LOO", "WATERFALL", "CRICKETS", "PRISON", "PRISON_ALARM", 
	"GANG_DUMPED", "SMUG_LAUGH", "PRISON_YARD", "PRISON_RIOT", "GANG_LOCKED_IN_BUS", "SHOPPING_MALL", "CLOCK_TOWER", "YEEHA_BOMB", 
	"BOWLING_ALLEY", "CROWD_NOISE", "FAN_NOISE", "GENERATOR_LOSE_POWER", "SCREAM", "BOMB_TICK", "BOMB_TICK_SHIT", "DETECTED_MUMBLE", 
	"KRISHNA_CHANT", "CRYING", "ROCKET_LAUNCH_FAIL_CLICK", "ROCKET_FAIL_LAUGH", "POISONED", "POWER_PLANT", "MUMBLE", "JAZZ_CLUB", 
	"COUNTRY_CLUB", "PYLON", "DISGRACELAND", "BAR_2", "STRIP_CLUB", "TEMPLE_2", "GARAGE_OPEN", "GARAGE_CLOSE", "LET_ME_OUT"
};

const char *SCR_CARS[] = {
	"ALFA", "ALLARD", "AMDB4", "APC", "BANKVAN", "BMW", "BOXCAR", "BOXTRUCK", "BUG", "CAR9", "BUICK", "BUS", "COPCAR", "DART", "EDSEL", "CAR15", "FIAT", "FIRETRUK",
	"GRAHAM", "GT24640", "CAR20", "GTRUCK", "GUNJEEP", "HOTDOG", "HOTDOG_D1", "HOTDOG_D2", "HOTDOG_D3", "ICECREAM", "ISETLIMO", "ISETTA", "JEEP", "JEFFREY", 
	"LIMO", "LIMO2", "MEDICAR", "MERC", "MESSER", "MIURA", "MONSTER", "MORGAN", "MORRIS", "PICKUP", "RTYPE", "CAR43", "SPIDER", "SPRITE", "STINGRAY", "STRATOS", 
	"STRATOSB", "STRIPETB", "STYPE", "STYPECAB", "SWATVAN", "T2000GT", "TANK", "TANKER", "TAXI", "TBIRD", "TOWTRUCK", "TRAIN", "TRAINCAB", "TRAINFB", "TRANCEAM",
	"TRUKCAB1", "TRUKCAB2", "TRUKCONT", "TRUKTRNS", "TVVAN", "VAN", "VESPA", "VTYPE", "WBTWIN", "WRECK0", "WRECK1", "WRECK2", "WRECK3", "WRECK4", "WRECK5", 
	"WRECK6", "WRECK7", "WRECK8", "WRECK9", "XK120", "ZCX5", "EDSELFBI", "HOTDOG_D4", "KRSNABUS"
};

const char *SCR_OBJECTS[] = {
	"", "BIN_LID", "BOLLARD", "CONE", "BOXES", "BLASTER", "RUBBISH", "BIN", "ANIMATING_OIL", "OIL", "MINE", "BUSH", "CRATE", "FOOTY", "HARDBOX", "NEWSDIS", 
	"OILDRUM", "TYRE", "HYDRANT_LID", "HYDRANT", "HYDRANT_UNLID", "ROADBLOCK", "BENCH", "PACKAGE", "", "TOWER", "", "", "", "", "", "", "", "", "", "", "", 
	"", "", "", "", "", "EXPLODE_MEDIUM", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "MOVING_COLLECT_00", "MOVING_COLLECT_01", 
	"MOVING_COLLECT_02", "MOVING_COLLECT_03", "MOVING_COLLECT_04", "MOVING_COLLECT_05", "MOVING_COLLECT_06", "MOVING_COLLECT_07", "MOVING_COLLECT_08", "MOVING_COLLECT_09",
	"MOVING_COLLECT_10", "MOVING_COLLECT_11", "MOVING_COLLECT_12", "MOVING_COLLECT_13", "MOVING_COLLECT_14", "MOVING_COLLECT_15", "MOVING_COLLECT_16", "MOVING_COLLECT_17",
	"MOVING_COLLECT_18", "MOVING_COLLECT_19", "MOVING_COLLECT_20", "MOVING_COLLECT_21", "MOVING_COLLECT_22", "MOVING_COLLECT_23", "MOVING_COLLECT_24", "MOVING_COLLECT_25",
	"MOVING_COLLECT_26", "MOVING_COLLECT_27", "MOVING_COLLECT_28", "MOVING_COLLECT_29", "MOVING_COLLECT_30", "MOVING_COLLECT_31", "MOVING_COLLECT_32", "MOVING_COLLECT_33",
	"MOVING_COLLECT_34", "MOVING_COLLECT_35", "MOVING_COLLECT_36", "MOVING_COLLECT_37", "MOVING_COLLECT_38", "MOVING_COLLECT_39", "MOVING_COLLECT_40", "MOVING_COLLECT_41",
	"MOVING_COLLECT_42", "MOVING_COLLECT_43", "MOVING_COLLECT_44", "SMALL_ARROW", "", "BLOOD_SPARK", "", "PARTICLE_SYSTEM", "FIREJET", "", "SMALL_BROWN_SKID", 
	"SMALL_GREY_SKID", "SMALL_RED_SKID", "MEDIUM_BROWN_SKID", "MEDIUM_GREY_SKID", "MEDIUM_RED_SKID", "CAR_CROSSING", "CAR_STOP", "BIG_WHITE_SKID", "MEDIUM_WHITE_SKID", 
	"SMALL_WHITE_SKID", "", "ROCKET", "BUS_STOP_MARKER", "CAR_SHOP", "BUSY_CAR_SHOP", "CAR_BOMB", "", "", "", "", "", "MOLOTOV_MOVING", "", "", "", "", "", 
	"HUGE_RED_SKID", "HUGE_WHITE_SKID", "HUGE_BROWN_SKID", "HUGE_GREY_SKID", "TANKTOP", "ANTENNA", "", "ANIMATING_RUBBISH", "DEAD_RUBBISH", "", "", "MOVING_CONE", "", 
	"MOVING_BIN", "MOVING_BIN_LID", "", "", "", "", "PHONE", "PHONE_RINGING", "", "", "", "", "", "", "", "", "", "PHONE_DEAD", "BRIEFCASE", "RED_PHONE", 
	"RED_PHONE_RINGING", "YELLOW_PHONE", "YELLOW_PHONE_RINGING", "GREEN_PHONE", "GREEN_PHONE_RINGING", "GRENADE", "", "", "", "", "", "", "", "", "", "SHOT", "", 
	"FLAMING_BULLET", "", "", "FIRE", "WATER_BULLET", "", "COLLECT_00", "COLLECT_01", "COLLECT_02", "COLLECT_03", "COLLECT_04", "COLLECT_05", "COLLECT_06", "COLLECT_07", 
	"COLLECT_08", "COLLECT_09", "COLLECT_10", "COLLECT_11", "COLLECT_12", "COLLECT_13", "COLLECT_14", "COLLECT_15", "COLLECT_16", "COLLECT_17", "COLLECT_18", "COLLECT_19",
	"COLLECT_20", "COLLECT_21", "COLLECT_22", "COLLECT_23", "COLLECT_24", "COLLECT_25", "COLLECT_26", "COLLECT_27", "COLLECT_28", "COLLECT_29", "COLLECT_30", "COLLECT_31",
	"COLLECT_32", "COLLECT_33", "COLLECT_34", "COLLECT_35", "COLLECT_36", "COLLECT_37", "COLLECT_38", "COLLECT_39", "COLLECT_40", "COLLECT_41", "COLLECT_42", "COLLECT_43",
	"COLLECT_44", "", "", "BOMB", "", "BIG_BROWN_SKID", "BIG_GREY_SKID", "", "", "BIG_RED_SKID", "BULLET", "TRAFFIC_LIGHT", "RED_FOOTPRINTS", "BLOOD", "CROSSING", "SPARK",
	"", "", "", "", "", "PISTOL_BULLET", "BONUS_TOKEN", "", "", "", "", "", "", "", "", "", "", "TASER_BULLET", "", "SOUND_INSTANT", "INVISIBLE_TARGET", "POWERGEN", 
	"POWERGEN_DEAD", "INVISIBLE_DESTRUCTIBLE", "GENLITE", "INVISIBLE_DEAD", "KILL_FRENZY", "", "", "", "", "", "", "", "TUNNEL_BLOCKER", "REMOTE"
};

//////////////////////////////////////////
// these strings arent required for decompiling (save some space for public release final version exe), used only for debugging:
#ifdef SCR_INCLUDE_DEBUG
const char *SCR_COMMANDS[] = {
	"(0)", "(1)", "(2)", "(3)", "(4)", "PLAYER_PED", "CHAR_DEC", "CHAR_DECSET_2D", "CHAR_DECSET_3D", "CAR_DEC", "CAR_DECSET_2D", "CAR_DECSET_3D", 
	"CAR_DECSET_2D_STR", "CAR_DECSET_3D_STR", "OBJ_DEC", "OBJ_DECSET_2D", "OBJ_DECSET_3D", "OBJ_DECSET_2D_INT", "OBJ_DECSET_3D_INT", "OBJ_DECSET_2D_STR", "OBJ_DECSET_3D_STR", 
	"COUNTER", "COUNTER_SET", "ARROW_DEC", "THREAD_ID", "CONVEYOR_DEC", "CONVEYOR_DECSET1", "CONVEYOR_DECSET2", "GENERATOR_DEC", "GENERATOR_DECSET1", "GENERATOR_DECSET2", 
	"GENERATOR_DECSET3", "GENERATOR_DECSET4", "DESTRUCTOR_DEC", "DESTRUCTOR_DECSET1", "DESTRUCTOR_DECSET2", "CRANE_DEC", "CRANE_BASIC_DEC", "CRANE_TARGET_DEC", 
	"CRANE2TARGET_DEC", "CRUSHER_BASIC", "CREATE_CHAR_2D", "CREATE_CHAR_3D", "CREATE_CAR_2D", "CREATE_CAR_3D", "CREATE_CAR_2D_STR", "CREATE_CAR_3D_STR", "CREATE_OBJ_2D", 
	"CREATE_OBJ_3D", "CREATE_OBJ_3D_INT", "CREATE_OBJ_2D_INT", "CREATE_OBJ_3D_STR", "CREATE_OBJ_2D_STR", "CREATE_CONVEYOR_2D", "CREATE_CONVEYOR_3D", "CREATE_GENERATOR_2D", 
	"CREATE_GENERATOR_3D", "CREATE_DESTRUCTOR_2D", "CREATE_DESTRUCTOR_3D", "LEVELSTART", "LEVELEND", "CREATE_THREAD", "STOP_THREAD", "START_EXEC", "STOP_EXEC", 
	"FOR_LOOP", "DO_WHILE", "FUNCTION", "RETURN", "WHILE", "WHILE_EXEC", "NOT", "AND", "OR", "IF", "THEN", "ELSE", "GOTO", "GOSUB", "S_PLUS_I", "I_PLUS_S", 
	"S_PLUS_S", "S_MINUS_I", "I_MINUS_S", "S_MINUS_S", "SET", "S_LESS_I", "S_LESS_S", "S_LEQUAL_I", "S_LEQUAL_S", 
	"S_GREATER_I", "S_GREATER_S", "S_GEQUAL_I", "S_GEQUAL_S", "S_EQUAL_I", "S_EQUAL_S", "INCREMENT", "DECREMENT", "IF_JUMP", 
	"FORWARD_DECLARE", "MAKE_CAR_DUMMY", "MAP_ZONE1", "MAP_ZONE_SET", "SET_CAR_DENSITY", "SET_GOOD_CAR", "SET_BAD_CAR", "SET_POLICE_CAR", "SET_PED_DENSITY", 
	"SET_MUGGER", "SET_CARTHIEF", "SET_ELVIS", "SET_GANG", "SET_POLICE_PED", "POINT_ARROW_AT", "POINT_ARROW_3D", "ARROW_COLOUR", "REMOVE_ARROW", "DISPLAY_MESSAGE", 
	"DISPLAY_BRIEF", "DISPLAY_TIMER", "CLEAR_TIMERS", "IS_CHAR_IN_CAR", "IS_CHAR_IN_MODEL", "IS_CHAR_IN_ANY_CAR", "IS_CHAR_STOPPED", "IS_CHAR_STUNNED", "CHECK_HEALTH", 
	"HAS_CHAR_DIED", "STORE_CAR_INFO", "CHECK_CAR_DAMAGE", "CHECK_CAR_DRIVER", "SET_CHAR_OBJ1", "SET_CHAR_OBJ2", "SET_CHAR_OBJ3", "IS_CHAR_OBJ_PASS", "IS_CHAR_OBJ_FAIL", 
	"SEND_CHAR_FOOT", "SEND_CHAR_CAR", "GIVE_WEAPON1", "IS_CAR_IN_BLOCK", "DELETE_ITEM", "ADD_SCORE1", "EXPLODE", "EXPLODE_BUILDING", "EXPLODE_ITEM", "LOCATE_CHAR_ANY", 
	"LOCATE_CHAR_ONFOOT", "LOCATE_CHAR_BY_CAR", "STOP_LOCATE_CHAR_ANY", "STOP_LOCATE_CHAR_FOOT", "STOP_LOCATE_CHAR_CAR", "SET_THREAT_SEARCH", "SET_THREAT_REACT", 
	"ADD_GROUP", "IS_CAR_WRECKED", "CHANGE_CAR_REMAP", "CHANGE_CHAR_REMAP", "CHECK_CAR_MODEL", "CHECK_CAR_REMAP", "CHECK_CAR_BOTH", "IS_ITEM_ONSCREEN", "DELAY_HERE", 
	"DELAY", "CLEAR_WANTED_LEVEL", "ALT_WANTED_LEVEL", "IS_CHAR_FIRE_ONSCREEN", "DRIVER_OUT_CAR", "CHAR_TO_DRIVE_CAR", "ANSWER_PHONE", "SEND_CAR_TO_BLOCK", 
	"GIVE_DRIVER_BRAKE", "CHAR_TO_BACKDOOR", "PLAY_SOUND", "SET_NO_COLLIDE", "CLEAR_NO_COLLIDE", "CAR_DRIVE_AWAY", "IS_CHAR_FIRING_AREA", "OPEN_DOOR", "CLOSE_DOOR", 
	"SET_DOOR_AUTO", "SET_DOOR_MANUAL", "ROAD_ON_OFF", "ADD_NEW_BLOCK", "REMOVE_BLOCK", "LOWER_LEVEL", "CHANGE_BLOCK_SIDE", "CHANGE_BLOCK_LID", "CHANGE_BLOCK_TYPE", 
	"GET_CAR_FROM_CRANE", "CAR_WRECK_IN_LOCATION", "CAR_SUNK", "CAR_IN_AIR", "CHECK_NUM_LIVES", "GET_NUM_LIVES", "CHECK_SCORE", "GET_SCORE", "CHECK_MULT", 
	"GET_MULT", "CHECK_RESPECT_GREATER", "CHECK_RESPECT_LESS", "CAR_DAMAGE_POS", "GET_PASSENGER_NUM", "CHAR_IN_AIR", "CHAR_SUNK", "LAST_WEAPON_HIT", "ADD_PATROL_POINT", 
	"GET_CAR_SPEED", "GET_CHAR_CAR_SPEED", "CHECK_CAR_SPEED", "GET_MAX_SPEED", "THREAD_DECLARE1", "THREAD_DECLARE2", "THREAD_DECLARE3", "THREAD_DECLARE4", 
	"THREAD_DECLARE5", "ENABLE_THREAD", "DISABLE_THREAD", "LIGHT_DEC", "LIGHT_DECSET1", "CREATE_LIGHT1", "CHANGE_INTENSITY", "CHANGE_COLOUR", "CHANGE_RADIUS", 
	"SET_GANG_INFO1", "SET_GANG_RESPECT", "SET_CHAR_RESPECT", "SET_AMBIENT", "CHECK_PHONE", "CHECK_PHONETIMER", "STOP_PHONE_RING", "SET_DOOR_INFO", "CHECK_RESPECT_IS", 
	"IS_CHAR_IN_GANG", "TIMER_DECLARE", "CHECK_NUM_ALIVE", "ADD_CHAR_TO_GROUP", "REMOVE_CHAR", "SET_MIN_ALIVE", "SET_CHAR_SHOOT", "SET_CHAR_BRAVERY", "DECLARE_MISSION", 
	"HAS_CAR_WEAPON", "IS_CHAR_IN_ZONE", "IS_CHAR_HORN", "CHECK_MAX_PASS", "SET_PHONE_DEAD", "IS_TRAILER_ATT", "IS_CAR_ON_TRAIL", "ENABLE_CRANE", "DISABLE_CRANE", 
	"CAR_GOT_DRIVER", "SPOTTED_PLAYER", "GET_LAST_PUNCHED", "KILL_ALL_PASSENG", "IS_GROUP_IN_CAR", "PUNCHED_SOMEONE", "REMOVE_WEAPON", "DO_NOWT", "ADD_CHAR_TO_GANG", 
	"MAKE_LEADER", "PARK", "PARK_FINISHED", "CHANGE_RESPECT", "PHONE_TEMPLATE", "BEEN_PUNCHED_BY", "UPDATE_DOOR", "GIVE_WEAPON2", "IS_CAR_CRUSHED", "SWITCH_GENERATOR1", 
	"SWITCH_GENERATOR2", "CAR_IN_AREA", "REMOTE_CONTROL", "MISSIONSTART", "MISSIONEND", "LAUNCH_MISSION", "COUNTER_SAVE", "COUNTER_SET_SAVE", "SAVE_GAME", 
	"CHANGE_CAR_LOCK", "DISPLAY_BRIEF_NOW", "PARK_NO_RESPAWN", "ADD_LIVES", "ADD_MULTIPLIER", "SET_DIR_OF_TVVAN", "POINT_ONSCREEN", "SET_STATION", "SET_EMPTY_STATION", 
	"RADIOSTATION_DEC", "START_BONUS1", "START_BONUS2", "START_BONUS3", "START_BONUS4", "CHECK_BONUS1", "CHECK_BONUS2", "CHECK_BONUS3", "SET_STATION_4", "SET_STATION_3", 
	"SET_STATION_2", "SET_STATION_1", "SETUP_MODEL_CHECK", "MODEL_CHECK", "LIGHT_DECSET2", "CREATE_LIGHT2", "SET_CAR_GRAPHIC", "DECLARE_POLICE", "CARBOMB_ACTIVE", 
	"CHAR_DRIVE_AGGR", "CHAR_DRIVE_SPEED", "S_IS_S_MINUS_S", "S_IS_S_PLUS_S", "GIVE_CAR_ALARM", "CAR_BULLETPROOF", "CAR_ROCKETPROOF", "CAR_FLAMEPROOF", 
	"IS_ALARM_RINGING", "SET_CHAR_OBJ_FOLLOW", "PUT_CAR_ON_TRAILER", "CLEAR_BRIEFS", "CHECK_HEADS", "FINISH_LEVEL", "CHECK_WEAPONHIT", "DISPLAY_BRIEF_SOON", 
	"SET_GANG_INFO2", "MAP_ZONE2", "IS_CHAR_ON_FIRE", "BRIEF_ONSCREEN", "SOUND", "SOUND_DECSET", "CREATE_SOUND", "DO_EASY_PHONE", "CHAR_INTO_CAR", "DEL_GROUP_IN_CAR", 
	"S_IS_S_MINUS_I", "S_IS_S_PLUS_I", "S_IS_S_DIV_I", "S_IS_S_MULT_I", "S_IS_S_MOD_I", "S_IS_S_DIV_S", "S_IS_S_MULT_S", "S_IS_S_MOD_S", "SET_COUNTER_INT", 
	"SET_COUNTER_VAR", "ADD_SCORE2", "FINISH_SCORE", "TOTAL_MISSIONS", "TOTAL_SECRETS", "PASSED_FLAG", "1_PASSED_FLAG", "2_PASSED_FLAG", "3_PASSED_FLAG", "SUPPRESS_MODEL", 
	"SWITCH_GENERATOR3", "SWITCH_GENERATOR4", "DECLARE_CARLIST", "DECIDE_POWERUP", "CHAR_ARRESTED", "ONSCREEN_ACCURACY", "WARP_CHAR", "WEAP_HIT_CAR", "SET_GROUP_TYPE", 
	"CHAR_DO_NOTHING", "EMERG_LIGHTS", "CHECK_OBJ_MODEL", "CHAR_INVINCIBLE", "PED_GRAPHIC", "MAKE_MUGGERS", "ANY_WEAPON_HIT_CAR", "LOC_SECOND_CHAR", "STOP_CAR_DRIVE", 
	"IS_BUS_FULL", "NO_CHARS_OFF_BUS", "KILL_CHAR", "SET_GANGCARRATIO", "SET_SHADING_LEV", "SET_CAR_JAMMED", "DOOR_DECLARE_S1", "DOOR_DECLARE_S2", "DOOR_DECLARE_S3", 
	"DOOR_DECLARE_D1", "DOOR_DECLARE_D2", "DOOR_DECLARE_D3", "LOC_SEC_CHAR_CAR", "LOC_SEC_CHAR_ANY", "SET_RUN_SPEED", "SET_STAY_IN_CAR", "SET_USE_CAR_WEAPON", 
	"GANG_1_MISSION_TOTAL", "GANG_2_MISSION_TOTAL", "GANG_3_MISSION_TOTAL", "SECRETS_PASSED", "SECRETS_FAILED", "FINISH_MISSION", "ADDSCORE_NO_MULT", "CHANGE_GANG_RESP", 
	"CREATE_GANG_CAR1", "CREATE_GANG_CAR2", "CREATE_GANG_CAR3", "CREATE_GANG_CAR4", "EXPLODE_LARGE1", "EXPLODE_LARGE2", "SET_ENTER_STATUS", "BONUS_DECLARE", 
	"STORE_BONUS", "EXPLODE_SMALL1", "EXPLODE_SMALL2", "EXPLODE_NO_RING1", "EXPLODE_NO_RING2", "SET_ALL_CONTROLS", "SET_FAV_CAR", "GROUP_IN_AREA", 
	"SET_CHAR_OCCUPATION", "SET_KF_WEAPON", "CLEAR_KF_WEAPON", "ONSCREEN_COUNTER_DEC", "ADD_ONSCREEN_COUNTER", "CLEAR_COUNTER", "CLEAR_CLOCK_ONLY", "EMERG_LIGHTS_ON", 
	"CHANGE_POLICE", "DESTROY_GROUP", "CHECK_CURRENT_WEAPON", "ALTER_WANTED_LEVEL", "START_BASIC_KF", "DO_BASIC_KF", "SET_BONUS_RATING", "PARKED_CAR_DECSET_2D", 
	"PARKED_CAR_DECSET_3D", "PARKED_CAR_DECSET_2D_STR", "PARKED_CAR_DECSET_3D_STR", "DEC_GANG_1_FLAG", "DEC_GANG_2_FLAG", "DEC_GANG_3_FLAG", "DEATH_ARR_STATE", 
	"ADD_TIME", "CHAR_AREA_ANY_MEANS", "DEC_DEATH_BASE_1", "DEC_DEATH_BASE_2", "DEC_DEATH_BASE_3", "DO_SAVE_GAME", "DO_CRANE_POWERUP", "LEVEL_END_ARROW1", 
	"LEVEL_END_ARROW2", "SET_MODEL_WANTED", "CHECK_DEATH_ARR", "FORCE_CLEANUP", "SAVE_RESPECT", "RESTORE_RESPECT"
};
const char *get_scr_cmd_for_real(const Uint16 &index){
	if(index < 0 || index >= arrlen(SCR_COMMANDS)){
		return "<UNKNOWN_COMMAND>";
	}
	return SCR_COMMANDS[index];
}
#define get_scr_cmd(index) get_scr_cmd_for_real(index)
#else
#define get_scr_cmd(index) sprintf_str("<%d>", index).c_str()
#endif
